#ifndef EMITTINGBUTTON_H
#define EMITTINGBUTTON_H

#include <QPushButton>

class QTimer;

class EmittingButton:public QPushButton
{

    Q_OBJECT

private:
    double freq;
    int index;
    QTimer *timer;



public:
    EmittingButton(QWidget *parent, double, int);

signals:
    void buttonClicked(int);
    void buttonIsHold(int);

public slots:
    void buttonIsClicked();
    void buttonReleased();
    void timeout();


};

#endif // EMITTINGBUTTON_H
